==> apache-uniffle-0.6.0-incubating-src.tar.gz: apache-uniffle-0.6.0-incubating-src/integration-test/common/src/test/java/org/apache/uniffle/test/AccessCandidatesCheckerKerberizedHdfsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.test;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import org.apache.uniffle.common.KerberizedHdfsBase;
import org.apache.uniffle.coordinator.CoordinatorMetrics;

public class AccessCandidatesCheckerKerberizedHdfsTest extends KerberizedHdfsBase {

  @BeforeAll
  public static void beforeAll() throws Exception {
    testRunner = AccessCandidatesCheckerKerberizedHdfsTest.class;
    KerberizedHdfsBase.init();
  }

  @BeforeEach
  public void setUp() throws Exception {
    CoordinatorMetrics.register();
    initHadoopSecurityContext();
  }

  @AfterEach
  public void afterEach() throws Exception {
    CoordinatorMetrics.clear();
    removeHadoopSecurityContext();
  }

  @Test
  public void test() throws Exception {
    String candidatesFile =  kerberizedHdfs.getSchemeAndAuthorityPrefix() + "/test/access_checker_candidates";
    AccessCandidatesCheckerHdfsTest.createAndRunCases(
        kerberizedHdfs.getSchemeAndAuthorityPrefix(),
        candidatesFile,
        kerberizedHdfs.getFileSystem(),
        kerberizedHdfs.getConf()
    );
  }
}

==> apache-uniffle-0.7.0-incubating-src.tar.gz: apache-uniffle-0.7.0-incubating-src/integration-test/common/src/test/java/org/apache/uniffle/test/AccessCandidatesCheckerKerberizedHdfsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.test;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import org.apache.uniffle.common.KerberizedHdfsBase;
import org.apache.uniffle.coordinator.metric.CoordinatorMetrics;

public class AccessCandidatesCheckerKerberizedHdfsTest extends KerberizedHdfsBase {

  @BeforeAll
  public static void beforeAll() throws Exception {
    testRunner = AccessCandidatesCheckerKerberizedHdfsTest.class;
    KerberizedHdfsBase.init();
  }

  @BeforeEach
  public void setUp() throws Exception {
    CoordinatorMetrics.register();
    initHadoopSecurityContext();
  }

  @AfterEach
  public void afterEach() throws Exception {
    CoordinatorMetrics.clear();
    removeHadoopSecurityContext();
  }

  @Test
  public void test() throws Exception {
    String candidatesFile =  kerberizedHdfs.getSchemeAndAuthorityPrefix() + "/test/access_checker_candidates";
    AccessCandidatesCheckerHdfsTest.createAndRunCases(
        kerberizedHdfs.getSchemeAndAuthorityPrefix(),
        candidatesFile,
        kerberizedHdfs.getFileSystem(),
        kerberizedHdfs.getConf()
    );
  }
}
